@@ -15,10 +15,12 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
+#define _DEFAULT_SOURCE
+
 #include <config.h>
 
 #include <stdlib.h>
@@ -170,7 +172,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	unsigned char *ppm, *ptr;
 	unsigned char gtable[256];
 	int start;
-	int datasize, framesize, hdrsize, ppmsize;
+	int datasize, hdrsize, ppmsize;
 	int nb_frames=1;
 	unsigned char buf[0x8000];
 
@@ -237,9 +239,6 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		camera->pl->data_offset = start;
 	}
 
-	/* Retrieve frames */
-	framesize = datasize;
-
 	frame_data = malloc(datasize);
 	if (!frame_data) return GP_ERROR_NO_MEMORY;
 	icl_read_picture_data(camera->port, frame_data, datasize);
