@@ -1,4 +1,24 @@
-#define _BSD_SOURCE
+/* dc120.c
+ *
+ * Copyright (C) Scott Fritzinger
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
+#define _DEFAULT_SOURCE
 #define _POSIX_C_SOURCE 199309L
 #include "config.h"
 
@@ -6,7 +26,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
 #include <gphoto2/gphoto2.h>
 
 #include "dc120.h"
@@ -467,7 +486,8 @@ static int dc120_get_file_preview (Camera *camera, CameraFile *file, int file_nu
 		gp_file_append(file, buf, strlen(buf));
 	}
 
-	sleep(1); /* FIXME: why? */
+	gp_file_free(f);
+	/* sleep(1); */ /* FIXME: why?  ... Marcus: removed it for now.*/
 	return (GP_OK);
 }
 
