@@ -1,6 +1,6 @@
 /* konica.c
  *
- * Copyright  2001 Lutz Mller
+ * Copyright 2001 Lutz Mueller
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -25,8 +25,8 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <gphoto2.h>
-#include <gphoto2-port-log.h>
+#include <gphoto2/gphoto2.h>
+#include <gphoto2/gphoto2-port-log.h>
 
 #include "lowlevel.h"
 
@@ -53,7 +53,7 @@
 #define CHECK_NULL(r)     {if (!(r)) return (GP_ERROR_BAD_PARAMETERS);}
 
 static int
-k_check (GPContext *c, const char *rb)
+k_check (GPContext *c, const unsigned char *rb)
 {
 	switch ((rb[3] << 8) | rb[2]) {
 	case 0x0000:
@@ -690,16 +690,16 @@ k_get_information (GPPort *p, GPContext *c, KInformation *info)
 	CRF (c, l_send_receive (p, c, sb, 4, &rb, &rbs, 0, NULL, NULL), rb);
 
 	memset (info, 0, sizeof (KInformation));
-	strncpy (info->model,         &rb[ 8],  4);
-	strncpy (info->serial_number, &rb[12], 10);
+	strncpy (info->model,         (char *)&rb[ 8],  4);
+	strncpy (info->serial_number, (char *)&rb[12], 10);
 	info->hardware.major =         rb[22];
 	info->hardware.minor =         rb[23];
 	info->software.major =         rb[24];
 	info->software.minor =         rb[25];
 	info->testing.major  =         rb[26];
 	info->testing.minor  =         rb[27];
-	strncpy (info->name,          &rb[28], 22);
-	strncpy (info->manufacturer,  &rb[50], 30);
+	strncpy (info->name,          (char *)&rb[28], 22);
+	strncpy (info->manufacturer,  (char *)&rb[50], 30);
 
         free (rb);
         return (GP_OK);
@@ -1221,7 +1221,7 @@ k_localization_data_put (GPPort *p, GPContext *c,
         unsigned long i, j;
         unsigned char sb[16 + PACKET_SIZE];
 
-	gp_log (GP_LOG_DEBUG, "konica", "Uploading %i bytes localization "
+	gp_log (GP_LOG_DEBUG, "konica", "Uploading %ld bytes localization "
 		"data...", data_size);
 
 	CHECK_NULL (data);
@@ -1291,6 +1291,7 @@ k_localization_data_put (GPPort *p, GPContext *c,
 		}
 		CRF (c, result, rb);
                 free (rb);
+		rb = NULL;
                 i += PACKET_SIZE;
         }
 }
