@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #ifndef __LG_GSM_H__
@@ -30,8 +30,8 @@ typedef enum {
 } Model;
 
 int lg_gsm_init              (GPPort *port, Model *model, Info *info);
-int lg_gsm_get_picture_size  (GPPort *port, int pic);
-int lg_gsm_read_picture_data (GPPort *port, char *data, int size, int n);
+unsigned int lg_gsm_get_picture_size  (GPPort *port, int pic);
+int lg_gsm_read_picture_data (GPPort *port, char *data, unsigned int size, unsigned int n);
 int lg_gsm_list_files (GPPort *port, CameraList *list);
 
 #endif
