@@ -19,7 +19,7 @@
 *                                                                     *
 **********************************************************************/
 
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 
