@@ -1,7 +1,7 @@
 /*
-        Copyright  2000 Mariusz Zynel <mariusz@mizar.org> (gPhoto port)
-        Copyright  2000 Fredrik Roubert <roubert@df.lth.se> (idea)
-        Copyright  1999 Galen Brooks <galen@nine.com> (DC1580 code)
+        Copyright 2000 Mariusz Zynel <mariusz@mizar.org> (gPhoto port)
+        Copyright 2000 Fredrik Roubert <roubert@df.lth.se> (idea)
+        Copyright 1999 Galen Brooks <galen@nine.com> (DC1580 code)
 
         This file is part of the gPhoto project and may only be used,  modified,
         and distributed under the terms of the gPhoto project license,  COPYING.
@@ -24,10 +24,10 @@
 
 #include <stdlib.h>
 #include <stdarg.h>
-#include <sys/time.h>
 #include <sys/stat.h>
-#include <unistd.h>
+#ifdef HAVE_MEMORY_H
 #include <memory.h>
+#endif
 #include <string.h>
 
 #ifdef ENABLE_NLS
@@ -497,12 +497,11 @@ static int get_info_func (CameraFilesystem *fs, const char *folder,
         CHECK (index = gp_filesystem_number(camera->fs, folder, filename, context));
         index++;
 
-	info->file.fields = GP_FILE_INFO_TYPE | GP_FILE_INFO_NAME | GP_FILE_INFO_SIZE;
+	info->file.fields = GP_FILE_INFO_TYPE | GP_FILE_INFO_SIZE;
 	strcpy(info->file.type, GP_MIME_JPEG);
-        sprintf(info->file.name, DSC_FILENAMEFMT, index);
         info->file.size = dsc2_selectimage(camera, index, DSC_FULLIMAGE);
 
-	info->preview.fields = GP_FILE_INFO_TYPE | GP_FILE_INFO_NAME | GP_FILE_INFO_SIZE;
+	info->preview.fields = GP_FILE_INFO_TYPE | GP_FILE_INFO_SIZE;
 	strcpy(info->preview.type, GP_MIME_JPEG);
         info->preview.size = dsc2_selectimage(camera, index, DSC_THUMBNAIL);
 
@@ -536,7 +535,6 @@ static int get_file_func (CameraFilesystem *fs, const char *folder,
 	if (size < 0)
 		return (size);
 
-	CHECK (gp_file_set_name(file, filename));
 	CHECK (gp_file_set_mime_type(file, GP_MIME_JPEG));
 
         blocks = (size - 1)/DSC_BLOCKSIZE + 1;
@@ -554,21 +552,19 @@ static int get_file_func (CameraFilesystem *fs, const char *folder,
         return GP_OK;
 }
 
-static int put_file_func (CameraFilesystem *fs, const char *folder,
-			  CameraFile *file, void *user_data,
+static int put_file_func (CameraFilesystem *fs, const char *folder, const char *name,
+			  CameraFileType type, CameraFile *file, void *user_data,
 			  GPContext *context) {
         
 	Camera *camera = user_data;
         int             blocks, blocksize, i, result;
-	const char      *name;
 	const char      *data;
-	long int        size;
+	long unsigned int size;
 	unsigned int id;
 
-	gp_file_get_name(file, &name);
         gp_context_status(context, _("Uploading image: %s."), name);
 
-/*      We can not figure out file type, at least by now.
+/*      We can not figure out file type, at least by now. (? curious, mime type -Marcus)
 
         if (strcmp(file->type, "image/jpg") != 0) {
                 dsc_print_message(camera, "JPEG image format allowed only.");
@@ -626,7 +622,7 @@ static int delete_file_func (CameraFilesystem *fs, const char *folder,
 static int camera_about (Camera *camera, CameraText *about, GPContext *context) 
 {
         strcpy(about->text,
-                        _("Panasonic DC1580 gPhoto library\n"
+                        _("Panasonic DC1580 gPhoto2 library\n"
                         "Mariusz Zynel <mariusz@mizar.org>\n\n"
                         "Based on dc1000 program written by\n"
                         "Fredrik Roubert <roubert@df.lth.se> and\n"
