@@ -614,9 +614,9 @@ static const ValueNameType olysp500uz_reg_20_val_names[] = {
 	{ { 0x00 }, N_("Auto") },
 	{ { 0x01 }, N_("Daylight") },
 	{ { 0x03 }, N_("Tungsten") },
-	{ { 0x04 }, N_("Flourescent-1-home-6700K") },
-	{ { 0x05 }, N_("Flourescent-2-desk-5000K") },
-	{ { 0x06 }, N_("Flourescent-3-office-4200K") },
+	{ { 0x04 }, N_("Fluorescent-1-home-6700K") },
+	{ { 0x05 }, N_("Fluorescent-2-desk-5000K") },
+	{ { 0x06 }, N_("Fluorescent-3-office-4200K") },
 	{ { 0x09 }, N_("Dusk") },
 	{ { 0x0a }, N_("Preset") },
 	{ { 0xff }, N_("Cloudy") },
