@@ -22,7 +22,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #ifdef HAVE_LIBJPEG
 # include <jpeglib.h>
@@ -57,14 +56,16 @@
 
 static int
 blink2_getnumpics(
-    GPPort *port, GPContext *context,int *numpics
+    GPPort *port, GPContext *context, unsigned int *numpics
 ) {
-    char buf[6];
+    unsigned char buf[2];
     int ret;
     
-    ret = gp_port_usb_msg_read(port, BLINK2_GET_NUMPICS, 0x03, 0, buf, 2);
-    if (ret<GP_OK)
+    ret = gp_port_usb_msg_read(port, BLINK2_GET_NUMPICS, 0x03, 0, (char*)buf, 2);
+    if (ret < GP_OK)
 	return ret;
+    gp_log(GP_LOG_DEBUG, "blink2","ret is %d", ret);
+    if (ret < 2) return GP_ERROR_IO_READ;
     *numpics = (buf[0]<<8) | buf[1];
     return GP_OK;
 }
@@ -93,8 +94,9 @@ static int
 file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 		void *data, GPContext *context)
 {
-	Camera *camera = data;
-	int	i, ret, numpics, bytes;
+	Camera		*camera = data;
+	int		i, ret;
+	unsigned int	bytes, numpics;
 	unsigned char	*xbuf, buf[8];
 
 	ret = blink2_getnumpics( camera->port, context, &numpics );
@@ -107,11 +109,13 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 		free(xbuf);
 		return ret;
 	}
+	if (ret < 1) return GP_ERROR_IO_READ;
 	ret = gp_port_read( camera->port, (char*)xbuf, bytes);
 	if (ret < GP_OK) {
 		free(xbuf);
 		return ret;
 	}
+	if (ret < bytes) return GP_ERROR_IO_READ;
 	for ( i=0; i < numpics; i++) {
 		char name[20];
 		if (xbuf[8*(i+1)])
@@ -121,7 +125,7 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 		gp_list_append( list, name, NULL);
 	}
 	free(xbuf);
-	return (GP_OK);
+	return GP_OK;
 }
 
 static int
@@ -131,7 +135,8 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 {
 	Camera *camera = data;
         int image_no, result;
-	int	i, ret, numpics, bytes;
+	int	i, ret;
+	unsigned int numpics, bytes;
 	unsigned char	*xbuf, buf[8];
 
 	struct xaddr {
@@ -156,12 +161,14 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		free(xbuf);
 		return ret;
 	}
+	if (ret < 1) return GP_ERROR_IO_READ;
 	ret = gp_port_read (camera->port, (char*)xbuf, bytes);
 	if (ret < GP_OK) {
 		free(addrs);
 		free(xbuf);
 		return ret;
 	}
+	if (ret < bytes) return GP_ERROR_IO_READ;
 	for ( i=0; i < numpics; i++) {
 		int end, start;
 
@@ -171,6 +178,10 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		end = 	(xbuf[8*i+13] << 16) |
 			(xbuf[8*i+14] <<  8) |
 			(xbuf[8*i+15]);
+
+		if (end < start)
+			return GP_ERROR_IO_READ;
+
 		addrs[i].start = start;
 		addrs[i].len = (end-start)/4;
 		addrs[i].type = xbuf[8*(i+1)];
@@ -183,14 +194,18 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		free(addrs);
                 return image_no;
 	}
+	if (image_no >= numpics) {
+		free(addrs);
+		gp_log(GP_LOG_DEBUG, "blink2","image %d requested, but only %d pics on camera?", image_no, numpics);
+                return GP_ERROR;
+	}
         switch (type) {
         case GP_FILE_TYPE_NORMAL:
 #ifdef HAVE_LIBJPEG
 {
 		char *convline,*convline2,*rawline;
 		unsigned char	*jpegdata;
-		unsigned int start, len, pitch;
-		int curread;
+		unsigned int curread, start, len, pitch;
 		struct jpeg_decompress_struct	dinfo;
 		struct jpeg_source_mgr		xjsm;
 		struct jpeg_error_mgr		jerr;
@@ -202,6 +217,11 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
         		gp_file_set_mime_type (file, GP_MIME_JPEG);
 		start = addrs[image_no].start;
 		len = addrs[image_no].len;
+
+		if (len >= UINT_MAX / 8) {
+			result = GP_ERROR_NO_MEMORY;
+			break;
+		}
 		jpegdata = (unsigned char*)malloc (len*8);
 		if (!jpegdata) {
 			result = GP_ERROR_NO_MEMORY;
@@ -224,11 +244,12 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		curread  = 0;
 		do {
 			int res;
-			res = gp_port_read (camera->port, (char*)(jpegdata+curread), len );
+			res = gp_port_read (camera->port, (char*)(jpegdata+curread), len-curread );
 			if (res < GP_OK) {
 				result = GP_OK;
 				break;
 			}
+			if (!res) break;
 			curread += res;
 		} while (curread<=len);
 
@@ -254,9 +275,6 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 
 		pitch = (dinfo.output_width*dinfo.output_components+3)&~3;
 
-		if (ret != JPEG_HEADER_OK)
-			return GP_ERROR;
-
 		rawline = malloc(pitch);
 		convline = malloc(dinfo.output_width*2*3);
 		convline2 = malloc(dinfo.output_width*2*2*3);
@@ -359,14 +377,16 @@ delete_all_func (CameraFilesystem *fs, const char *folder, void *data,
 	ret = gp_port_usb_msg_read( camera->port, BLINK2_DELETE_ALL, 0x03, 0, buf, 1);
 	if (ret < GP_OK)
 		return ret;
-        return (GP_OK);
+	if (ret < 1) return GP_ERROR_IO_READ;
+        return GP_OK;
 }
 
 static int
 camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
                 GPContext *context)
 {
-	int oldnumpics, numpics, ret;
+	int ret;
+	unsigned int oldnumpics, numpics;
 	char buf[1];
 	
 	ret = blink2_getnumpics (camera->port, context, &oldnumpics);
@@ -376,10 +396,12 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
 	ret = gp_port_usb_msg_read( camera->port, BLINK2_INIT_CAPTURE, 0x03, 0, buf, 1);
 	if (ret < GP_OK)
 		return ret;
+	if (ret < 1) return GP_ERROR_IO_READ;
 	do {
 		ret = gp_port_usb_msg_read( camera->port, BLINK2_CHECK_CAPTURE_FINISH, 0x03, 0, buf, 1);
 		if (ret < GP_OK)
 			return ret;
+		if (ret < 1) return GP_ERROR_IO_READ;
 		sleep(1);
 	} while (buf[0] == 0x00);
 
@@ -455,8 +477,10 @@ camera_init (Camera *camera, GPContext *context)
 	ret = gp_port_usb_msg_read( camera->port, BLINK2_GET_FIRMWARE_ID, 0x03, 0, buf, 6);
 	if (ret < GP_OK)
 		return ret;
+	if (ret < 6) return GP_ERROR_IO_READ;
 	ret = gp_port_usb_msg_read( camera->port, 0x04, 0x03, 0, buf, 1);
 	if (ret < GP_OK)
 		return ret;
+	if (ret < 1) return GP_ERROR_IO_READ;
 	return GP_OK;
 }
