@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 #ifndef __SMAL_H__
 
@@ -23,5 +23,27 @@
 
 #define USB_VENDOR_ID_SMAL        0x0dca
 #define USB_DEVICE_ID_ULTRAPOCKET 0x0002
+#define USB_DEVICE_ID_FLATFOTO    0x0004
+
+#define USB_VENDOR_ID_LOGITECH    0x046d
+#define USB_DEVICE_ID_POCKETDIGITAL 0x0950
+
+#define USB_VENDOR_ID_CREATIVE    0x041e
+#define USB_DEVICE_ID_CARDCAM 0x4016
+
+typedef enum ultrapocket_BADGE_TYPE {
+    BADGE_UNKNOWN = 0,
+    BADGE_GENERIC,    /* could be axia/ultrapocket */
+    BADGE_ULTRAPOCKET,
+    BADGE_AXIA,
+    BADGE_FLATFOTO,
+    BADGE_LOGITECH_PD, /* pocket digital */
+    BADGE_CARDCAM
+} up_badge_type;
+
+struct _CameraPrivateLibrary {
+    up_badge_type up_type;
+};
+
 
 #endif
