@@ -17,8 +17,8 @@
  * \par
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -55,6 +55,7 @@ static struct {
 	{GP_ERROR_CANCEL,              N_("Operation cancelled")},
 	{GP_ERROR_CAMERA_ERROR,        N_("Camera could not complete operation")},
 	{GP_ERROR_OS_FAILURE,          N_("OS error in camera communication")},
+	{GP_ERROR_NO_SPACE,            N_("Not enough free space")},
 	{0, NULL}
 };
 
