@@ -17,8 +17,8 @@
  * \par
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -34,6 +34,24 @@ const char **gp_library_version(GPVersionVerbosity verbose)
 	static const char *shrt[] =
 		{
 			PACKAGE_VERSION,
+#if GP_CAMLIB_SET_IS_NONSTANDARD
+			"NON-STANDARD CAMLIB SET"
+			" ("
+			GP_CAMLIB_SET
+#ifdef GP_CAMLIB_SET_SKIPPING
+			" SKIPPING "
+			GP_CAMLIB_SET_SKIPPING
+#endif
+			")",
+#else
+			"standard camlibs"
+#ifdef GP_CAMLIB_SET_SKIPPING
+			" (SKIPPING "
+			GP_CAMLIB_SET_SKIPPING
+			")"
+#endif
+			,
+#endif
 #ifdef HAVE_CC
 			HAVE_CC,
 #else
@@ -54,6 +72,31 @@ const char **gp_library_version(GPVersionVerbosity verbose)
 	static const char *verb[] =
 		{
 			PACKAGE_VERSION,
+#if GP_CAMLIB_SET_IS_NONSTANDARD
+			"NON-STANDARD CAMLIB SET"
+#ifdef GP_CAMLIB_SET_SKIPPING
+			" SKIPPING SOME"
+#endif
+			" ("
+			GP_CAMLIB_SET
+#ifdef GP_CAMLIB_SET_SKIPPING
+			" SKIPPING "
+			GP_CAMLIB_SET_SKIPPING
+#endif
+			")",
+#else
+			"standard camlib set"
+#ifdef GP_CAMLIB_SET_SKIPPING
+			" SKIPPING SOME"
+#endif
+			" ("
+			GP_CAMLIB_SET
+#ifdef GP_CAMLIB_SET_SKIPPING
+			" SKIPPING "
+			GP_CAMLIB_SET_SKIPPING
+#endif
+			")",
+#endif
 #ifdef HAVE_CC
 			HAVE_CC " (C compiler used)",
 #else
