@@ -1,18 +1,17 @@
 /*
-@ @licstart  The following is the entire license notice for the
+@licstart  The following is the entire license notice for the
 JavaScript code in this file.
 
-Copyright (C) 1997-2017 by Dimitri van Heesch
+Copyright (C) 1997-2019 by Dimitri van Heesch
 
 This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+it under the terms of version 2 of the GNU General Public License as published by
+the Free Software Foundation
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program; if not, write to the Free Software Foundation, Inc.,
@@ -52,9 +51,9 @@ var NAVTREEINDEX =
 "__stdint_8h_source.html",
 "gphoto2-camera_8h.html#a8fa6903e3bf0ab26edc4e915512aa44f",
 "gphoto2-filesys_8h.html#a6f6d981b8ab1273e8048df66670782ab",
-"gphoto2-port-version_8c.html#a293e53d10075f8c09b39325d8e54be43",
-"jpeg_8c.html#a2cc14f63e9eb5bac86a036771bfb1758",
-"struct__CameraStorageInformation.html#a8bd76351601c330356c8656cc0e580f1"
+"gphoto2-port-version_8c.html",
+"jpeg_8c.html#a2a7832a90410c88f8f4d1f99ff64c461",
+"struct__CameraStorageInformation.html#a8b96dab747312da81a5b0702882b002b"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
