@@ -113,67 +113,68 @@ var NAVTREEINDEX1 =
 "gphoto2-file_8c.html#af0d1d638d7a58ae9591be458eeb13c72":[2,0,2,12,16],
 "gphoto2-file_8c.html#afe4a2c1685df174f61f20b2986edd93b":[2,0,2,12,11],
 "gphoto2-file_8h.html":[2,0,1,3],
-"gphoto2-file_8h.html#a0376d5d1c7af0edde33cdbe7f3d2eb1e":[2,0,1,3,42],
-"gphoto2-file_8h.html#a14a65df63ea8de52cca12e2596000e92":[2,0,1,3,36],
-"gphoto2-file_8h.html#a25264cb44a28b7a8e0a401a8853e7bee":[2,0,1,3,9],
+"gphoto2-file_8h.html#a0376d5d1c7af0edde33cdbe7f3d2eb1e":[2,0,1,3,43],
+"gphoto2-file_8h.html#a14a65df63ea8de52cca12e2596000e92":[2,0,1,3,37],
+"gphoto2-file_8h.html#a25264cb44a28b7a8e0a401a8853e7bee":[2,0,1,3,10],
 "gphoto2-file_8h.html#a2b5a9e50b018b3e7562ab2539c86cfb0":[2,0,1,3,3],
-"gphoto2-file_8h.html#a39cd4453e509f9b56b7703ae076fe42a":[2,0,1,3,11],
-"gphoto2-file_8h.html#a4415b2867b1a8d6c032018db99fd3fee":[2,0,1,3,37],
-"gphoto2-file_8h.html#a4f9427331e166c410827eafe8c7316d2":[2,0,1,3,26],
+"gphoto2-file_8h.html#a39cd4453e509f9b56b7703ae076fe42a":[2,0,1,3,12],
+"gphoto2-file_8h.html#a4415b2867b1a8d6c032018db99fd3fee":[2,0,1,3,38],
+"gphoto2-file_8h.html#a4f9427331e166c410827eafe8c7316d2":[2,0,1,3,27],
 "gphoto2-file_8h.html#a51e56d5d6503f1e2144390476565f2e6":[2,0,1,3,5],
-"gphoto2-file_8h.html#a56b4ae20b0bebc37495b70b9d3cb0250":[2,0,1,3,17],
-"gphoto2-file_8h.html#a56e413d5ea3abc6e512b92c5861b9594":[2,0,1,3,46],
-"gphoto2-file_8h.html#a58b455d8aa49d2a01429ce3475c9f873":[2,0,1,3,39],
-"gphoto2-file_8h.html#a5dc4e763bf9242925f7d3223c125be70":[2,0,1,3,14],
-"gphoto2-file_8h.html#a6b14aa2ac7af75fc48125d515fb63038":[2,0,1,3,51],
-"gphoto2-file_8h.html#a6fca699d500239610e276fef064adc2f":[2,0,1,3,32],
-"gphoto2-file_8h.html#a73b0c6e00946621ea45b3a04d92165a2":[2,0,1,3,30],
-"gphoto2-file_8h.html#a77b7d521ef9e2bf405e97717dd836d43":[2,0,1,3,44],
-"gphoto2-file_8h.html#a7b2e75dd7e752422fa09d3aa19ad83be":[2,0,1,3,10],
-"gphoto2-file_8h.html#a804a2636dc2eb6676076c39b079e2da6":[2,0,1,3,13],
-"gphoto2-file_8h.html#a869d3b2d687abf139c553ad2c459f637":[2,0,1,3,21],
-"gphoto2-file_8h.html#a874cdc7c50e2946e4fe96794a61766af":[2,0,1,3,43],
-"gphoto2-file_8h.html#a8c25e53c58797c026803930fe73e7aea":[2,0,1,3,23],
-"gphoto2-file_8h.html#a8d2987f25dfa8f4c1935b129583edb9a":[2,0,1,3,7],
-"gphoto2-file_8h.html#a9a0e206ef504c2c74da44c4649842da1":[2,0,1,3,20],
-"gphoto2-file_8h.html#a9aa6499669a0ab66844030440655a0ff":[2,0,1,3,33],
-"gphoto2-file_8h.html#aa09aade5ad507d71522baae8c6bfdcaa":[2,0,1,3,16],
-"gphoto2-file_8h.html#aa330c62c510ed9c05a678a319ff807a6":[2,0,1,3,52],
-"gphoto2-file_8h.html#aa74b5ef3f426b9a97ef4cde4e04225d5":[2,0,1,3,47],
+"gphoto2-file_8h.html#a56b4ae20b0bebc37495b70b9d3cb0250":[2,0,1,3,18],
+"gphoto2-file_8h.html#a56e413d5ea3abc6e512b92c5861b9594":[2,0,1,3,47],
+"gphoto2-file_8h.html#a58b455d8aa49d2a01429ce3475c9f873":[2,0,1,3,40],
+"gphoto2-file_8h.html#a5dc4e763bf9242925f7d3223c125be70":[2,0,1,3,15],
+"gphoto2-file_8h.html#a6b14aa2ac7af75fc48125d515fb63038":[2,0,1,3,52],
+"gphoto2-file_8h.html#a6fca699d500239610e276fef064adc2f":[2,0,1,3,33],
+"gphoto2-file_8h.html#a73b0c6e00946621ea45b3a04d92165a2":[2,0,1,3,31],
+"gphoto2-file_8h.html#a77b7d521ef9e2bf405e97717dd836d43":[2,0,1,3,45],
+"gphoto2-file_8h.html#a7b2e75dd7e752422fa09d3aa19ad83be":[2,0,1,3,11],
+"gphoto2-file_8h.html#a804a2636dc2eb6676076c39b079e2da6":[2,0,1,3,14],
+"gphoto2-file_8h.html#a869d3b2d687abf139c553ad2c459f637":[2,0,1,3,22],
+"gphoto2-file_8h.html#a874cdc7c50e2946e4fe96794a61766af":[2,0,1,3,44],
+"gphoto2-file_8h.html#a8c25e53c58797c026803930fe73e7aea":[2,0,1,3,24],
+"gphoto2-file_8h.html#a8d2987f25dfa8f4c1935b129583edb9a":[2,0,1,3,8],
+"gphoto2-file_8h.html#a9a0e206ef504c2c74da44c4649842da1":[2,0,1,3,21],
+"gphoto2-file_8h.html#a9aa6499669a0ab66844030440655a0ff":[2,0,1,3,34],
+"gphoto2-file_8h.html#aa09aade5ad507d71522baae8c6bfdcaa":[2,0,1,3,17],
+"gphoto2-file_8h.html#aa330c62c510ed9c05a678a319ff807a6":[2,0,1,3,53],
+"gphoto2-file_8h.html#aa51a9f8b27edbc3b5ebbe7f13b98ce82":[2,0,1,3,7],
+"gphoto2-file_8h.html#aa74b5ef3f426b9a97ef4cde4e04225d5":[2,0,1,3,48],
 "gphoto2-file_8h.html#aaf282b27f273b78665aa47754dffe7bf":[2,0,1,3,1],
-"gphoto2-file_8h.html#ab0c9c2ff2ef54f2ead016ed5a82f895f":[2,0,1,3,48],
-"gphoto2-file_8h.html#ab1601098b75b7e6f0eaa91f9105fceec":[2,0,1,3,22],
-"gphoto2-file_8h.html#ab2fc202bdab8503ab5dca38357dff494":[2,0,1,3,50],
-"gphoto2-file_8h.html#ab5554e64015b042cc297a461be90d6c4":[2,0,1,3,27],
-"gphoto2-file_8h.html#ab9c078f6915a3186c90ff81cc52da898":[2,0,1,3,40],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69":[2,0,1,3,29],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a533cccf7871c3ddfe182425f0b1a06f9":[2,0,1,3,29,0],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a5f9e4fc5c19d2f49b1539d61ebc7d824":[2,0,1,3,29,5],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a8e7f28766023ea910ca6e34f4745f915":[2,0,1,3,29,3],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69aa8534dad4e3b2024cf8eae58fdbe940f":[2,0,1,3,29,1],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69adfc3456d99351d80f6d514cd130f8c62":[2,0,1,3,29,4],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69af9deb2f536e56d6546239f785c29f7c8":[2,0,1,3,29,2],
-"gphoto2-file_8h.html#aba965b1a676ea68194cb4052b3dea00d":[2,0,1,3,38],
+"gphoto2-file_8h.html#ab0c9c2ff2ef54f2ead016ed5a82f895f":[2,0,1,3,49],
+"gphoto2-file_8h.html#ab1601098b75b7e6f0eaa91f9105fceec":[2,0,1,3,23],
+"gphoto2-file_8h.html#ab2fc202bdab8503ab5dca38357dff494":[2,0,1,3,51],
+"gphoto2-file_8h.html#ab5554e64015b042cc297a461be90d6c4":[2,0,1,3,28],
+"gphoto2-file_8h.html#ab9c078f6915a3186c90ff81cc52da898":[2,0,1,3,41],
+"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69":[2,0,1,3,30],
+"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a533cccf7871c3ddfe182425f0b1a06f9":[2,0,1,3,30,0],
+"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a5f9e4fc5c19d2f49b1539d61ebc7d824":[2,0,1,3,30,5],
+"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a8e7f28766023ea910ca6e34f4745f915":[2,0,1,3,30,3],
+"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69aa8534dad4e3b2024cf8eae58fdbe940f":[2,0,1,3,30,1],
+"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69adfc3456d99351d80f6d514cd130f8c62":[2,0,1,3,30,4],
+"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69af9deb2f536e56d6546239f785c29f7c8":[2,0,1,3,30,2],
+"gphoto2-file_8h.html#aba965b1a676ea68194cb4052b3dea00d":[2,0,1,3,39],
 "gphoto2-file_8h.html#abfdcea806c848d1e959108b69642d3f9":[2,0,1,3,4],
-"gphoto2-file_8h.html#ac0058da71651fd4068306be65fa680cc":[2,0,1,3,35],
-"gphoto2-file_8h.html#ac31856165a1b0fb6e64b06a5a47b8cc7":[2,0,1,3,34],
-"gphoto2-file_8h.html#aca2b7ed7d1b91fcdb0578ee71142a101":[2,0,1,3,45],
-"gphoto2-file_8h.html#ad3ad5261f1b3eca778263e13db5ff308":[2,0,1,3,18],
-"gphoto2-file_8h.html#ad6107fa3f070c7f46bc2903275add9cc":[2,0,1,3,15],
+"gphoto2-file_8h.html#ac0058da71651fd4068306be65fa680cc":[2,0,1,3,36],
+"gphoto2-file_8h.html#ac31856165a1b0fb6e64b06a5a47b8cc7":[2,0,1,3,35],
+"gphoto2-file_8h.html#aca2b7ed7d1b91fcdb0578ee71142a101":[2,0,1,3,46],
+"gphoto2-file_8h.html#ad3ad5261f1b3eca778263e13db5ff308":[2,0,1,3,19],
+"gphoto2-file_8h.html#ad6107fa3f070c7f46bc2903275add9cc":[2,0,1,3,16],
 "gphoto2-file_8h.html#ad907d4ac340eaa9e2371726df5aa515a":[2,0,1,3,2],
 "gphoto2-file_8h.html#adb84f867bcc3df8e979aea52b06dbdef":[2,0,1,3,6],
-"gphoto2-file_8h.html#add71180e16fc7a5b933cef7b0cd989d6":[2,0,1,3,24],
-"gphoto2-file_8h.html#ade7379a5b38f498b2c550c45f58b400d":[2,0,1,3,25],
-"gphoto2-file_8h.html#ae17d5cf6651a094da8a035a5aec477e4":[2,0,1,3,8],
-"gphoto2-file_8h.html#ae2f0802d187957c104a3bb6925edc95a":[2,0,1,3,49],
-"gphoto2-file_8h.html#ae4575bab836285ea2c0765dec0660929":[2,0,1,3,12],
-"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842":[2,0,1,3,28],
-"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842a885208212a9c765895d48a3dddd54470":[2,0,1,3,28,1],
-"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842add357028781a405fed99210f321aa19f":[2,0,1,3,28,0],
-"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842af8d7ad7cfc3baaa5135ca835d4e388c7":[2,0,1,3,28,2],
-"gphoto2-file_8h.html#ae6f2318d561ce3ff3a37a1145a0e1de6":[2,0,1,3,19],
-"gphoto2-file_8h.html#af0d1d638d7a58ae9591be458eeb13c72":[2,0,1,3,41],
-"gphoto2-file_8h.html#afe87b1e2f9df858f3737bb0d603a0d6e":[2,0,1,3,31],
+"gphoto2-file_8h.html#add71180e16fc7a5b933cef7b0cd989d6":[2,0,1,3,25],
+"gphoto2-file_8h.html#ade7379a5b38f498b2c550c45f58b400d":[2,0,1,3,26],
+"gphoto2-file_8h.html#ae17d5cf6651a094da8a035a5aec477e4":[2,0,1,3,9],
+"gphoto2-file_8h.html#ae2f0802d187957c104a3bb6925edc95a":[2,0,1,3,50],
+"gphoto2-file_8h.html#ae4575bab836285ea2c0765dec0660929":[2,0,1,3,13],
+"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842":[2,0,1,3,29],
+"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842a885208212a9c765895d48a3dddd54470":[2,0,1,3,29,1],
+"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842add357028781a405fed99210f321aa19f":[2,0,1,3,29,0],
+"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842af8d7ad7cfc3baaa5135ca835d4e388c7":[2,0,1,3,29,2],
+"gphoto2-file_8h.html#ae6f2318d561ce3ff3a37a1145a0e1de6":[2,0,1,3,20],
+"gphoto2-file_8h.html#af0d1d638d7a58ae9591be458eeb13c72":[2,0,1,3,42],
+"gphoto2-file_8h.html#afe87b1e2f9df858f3737bb0d603a0d6e":[2,0,1,3,32],
 "gphoto2-file_8h_source.html":[2,0,1,3],
 "gphoto2-filesys_8c.html":[2,0,2,13],
 "gphoto2-filesys_8c.html#a083ea3fd7f794f6de09c1c51ba142572":[2,0,2,13,29],
@@ -248,6 +249,5 @@ var NAVTREEINDEX1 =
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a7c19dc619e18629df027df1f8aaa1035":[2,0,1,4,23,8],
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a7f0cc4ba19d9f92f2e8e12de6580f47b":[2,0,1,4,23,2],
 "gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9277302e076066219975e49bbc574600":[2,0,1,4,23,7],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9ed3048a35c2f6a59d6e89e52f24b1a5":[2,0,1,4,23,5],
-"gphoto2-filesys_8h.html#a6f6d981b8ab1273e8048df66670782ab":[2,0,1,4,52]
+"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9ed3048a35c2f6a59d6e89e52f24b1a5":[2,0,1,4,23,5]
 };
