@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"jpeg_8c.html#a2a7832a90410c88f8f4d1f99ff64c461":[2,0,2,20,15],
 "jpeg_8c.html#a2cc14f63e9eb5bac86a036771bfb1758":[2,0,2,20,12],
 "jpeg_8c.html#a30e48d4e0366699fcd210b93a4c6a4f8":[2,0,2,20,26],
 "jpeg_8c.html#a4aee2400e444196497aaf51b5bda674b":[2,0,2,20,17],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "struct__CameraStorageInformation.html#a2a263c93947db1b47bca9e7298840eca":[1,0,15,1],
 "struct__CameraStorageInformation.html#a468551e2079facf00b9acc97798fa30f":[1,0,15,2],
 "struct__CameraStorageInformation.html#a54d368755af52b0b4991e5cd8e706271":[1,0,15,5],
-"struct__CameraStorageInformation.html#a7e1cdd21daa0d4d710a66d35a2cee25a":[1,0,15,9],
-"struct__CameraStorageInformation.html#a8b96dab747312da81a5b0702882b002b":[1,0,15,7]
+"struct__CameraStorageInformation.html#a7e1cdd21daa0d4d710a66d35a2cee25a":[1,0,15,9]
 };
